@@ -1,9 +1,6 @@
 #!/bin/bash
 
 WORKING_DIR=$(pwd) # current/working directory
-sudo apt update
-pip3 install --upgrade pip
-pip3 install -r requirements.txt
 LIBRARY_PATH=$WORKING_DIR/../../../ximc/crossplatform/wrappers/python/libximc/library-files/
 LINUX_ARCH=$(uname -m)
 echo Current architecture: $LINUX_ARCH
@@ -32,4 +29,4 @@ then
   echo "${FULL_LIBRARY_PATH}"
   export LD_LIBRARY_PATH=${FULL_LIBRARY_PATH}
   python3 Extendtestpython.py
-fi
\ No newline at end of file
+fi
