@@ -1,4 +1,4 @@
-def set_profile_8MT18_13(lib, id):
+def set_profile_8MT167_100(lib, id):
     worst_result = Result.Ok
     result = Result.Ok
 
@@ -56,11 +56,11 @@ def set_profile_8MT18_13(lib, id):
 
     move_settings = move_settings_t()
 
-    move_settings.Speed = 457
+    move_settings.Speed = 1000
     move_settings.uSpeed = 0
     move_settings.Accel = 2000
     move_settings.Decel = 4000
-    move_settings.AntiplaySpeed = 457
+    move_settings.AntiplaySpeed = 1000
     move_settings.uAntiplaySpeed = 0
     class MoveFlags_:
         RPM_DIV_1000 = 1
@@ -73,9 +73,9 @@ def set_profile_8MT18_13(lib, id):
 
     engine_settings = engine_settings_t()
 
-    engine_settings.NomVoltage = 300
-    engine_settings.NomCurrent = 180
-    engine_settings.NomSpeed = 914
+    engine_settings.NomVoltage = 1
+    engine_settings.NomCurrent = 1200
+    engine_settings.NomSpeed = 5000
     engine_settings.uNomSpeed = 0
     class EngineFlags_:
         ENGINE_LIMIT_RPM = 128
@@ -86,8 +86,8 @@ def set_profile_8MT18_13(lib, id):
         ENGINE_MAX_SPEED = 4
         ENGINE_CURRENT_AS_RMS = 2
         ENGINE_REVERSE = 1
-    engine_settings.EngineFlags = EngineFlags_.ENGINE_LIMIT_RPM | EngineFlags_.ENGINE_ACCEL_ON | EngineFlags_.ENGINE_CURRENT_AS_RMS | EngineFlags_.ENGINE_REVERSE
-    engine_settings.Antiplay = 169
+    engine_settings.EngineFlags = EngineFlags_.ENGINE_LIMIT_RPM | EngineFlags_.ENGINE_ACCEL_ON | EngineFlags_.ENGINE_REVERSE
+    engine_settings.Antiplay = 575
     class MicrostepMode_:
         MICROSTEP_MODE_FRAC_256 = 9
         MICROSTEP_MODE_FRAC_128 = 8
@@ -99,7 +99,7 @@ def set_profile_8MT18_13(lib, id):
         MICROSTEP_MODE_FRAC_2 = 2
         MICROSTEP_MODE_FULL = 1
     engine_settings.MicrostepMode = MicrostepMode_.MICROSTEP_MODE_FRAC_256
-    engine_settings.StepsPerRev = 20
+    engine_settings.StepsPerRev = 200
     result = lib.set_engine_settings(id, byref(engine_settings))
 
     if result != Result.Ok:
@@ -137,7 +137,7 @@ def set_profile_8MT18_13(lib, id):
         POWER_SMOOTH_CURRENT = 4
         POWER_OFF_ENABLED = 2
         POWER_REDUCT_ENABLED = 1
-    power_settings.PowerFlags = PowerFlags_.POWER_SMOOTH_CURRENT | PowerFlags_.POWER_REDUCT_ENABLED
+    power_settings.PowerFlags = PowerFlags_.POWER_SMOOTH_CURRENT | PowerFlags_.POWER_OFF_ENABLED | PowerFlags_.POWER_REDUCT_ENABLED
     result = lib.set_power_settings(id, byref(power_settings))
 
     if result != Result.Ok:
@@ -182,9 +182,9 @@ def set_profile_8MT18_13(lib, id):
         ENDER_SW1_ACTIVE_LOW = 2
         ENDER_SWAP = 1
     edges_settings.EnderFlags = EnderFlags_.ENDER_SW2_ACTIVE_LOW | EnderFlags_.ENDER_SW1_ACTIVE_LOW | EnderFlags_.ENDER_SWAP
-    edges_settings.LeftBorder = -203
+    edges_settings.LeftBorder = 2000
     edges_settings.uLeftBorder = 0
-    edges_settings.RightBorder = 11089
+    edges_settings.RightBorder = 97000
     edges_settings.uRightBorder = 0
     result = lib.set_edges_settings(id, byref(edges_settings))
 
@@ -290,8 +290,8 @@ def set_profile_8MT18_13(lib, id):
 
     control_settings = control_settings_t()
 
-    control_settings.MaxSpeed[0] = 45
-    control_settings.MaxSpeed[1] = 457
+    control_settings.MaxSpeed[0] = 100
+    control_settings.MaxSpeed[1] = 1000
     control_settings.MaxSpeed[2] = 0
     control_settings.MaxSpeed[3] = 0
     control_settings.MaxSpeed[4] = 0
@@ -445,8 +445,8 @@ def set_profile_8MT18_13(lib, id):
 
     stage_information = stage_information_t()
 
-    stage_information.Manufacturer = bytes([0, 116, 97, 110, 100, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
-    stage_information.PartNumber = bytes([56, 77, 84, 49, 56, 45, 49, 51, 0, 48, 88, 89, 90, 0, 89, 90, 0, 0, 0, 0, 0, 69, 65, 83])
+    stage_information.Manufacturer = bytes([83, 116, 97, 110, 100, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
+    stage_information.PartNumber = bytes([56, 77, 84, 49, 54, 55, 45, 49, 48, 48, 0, 50, 56, 0, 0, 0, 48, 0, 48, 0, 0, 69, 65, 83])
     result = lib.set_stage_information(id, byref(stage_information))
 
     if result != Result.Ok:
@@ -455,15 +455,15 @@ def set_profile_8MT18_13(lib, id):
 
     stage_settings = stage_settings_t()
 
-    stage_settings.LeadScrewPitch = 0.3499999940395355
-    stage_settings.Units = bytes([0, 109, 0, 114, 101, 101, 0, 0])
-    stage_settings.MaxSpeed = 1
-    stage_settings.TravelRange = 13
-    stage_settings.SupplyVoltageMin = 0
-    stage_settings.SupplyVoltageMax = 0
+    stage_settings.LeadScrewPitch = 0.5
+    stage_settings.Units = bytes([109, 109, 0, 114, 101, 101, 0, 0])
+    stage_settings.MaxSpeed = 5
+    stage_settings.TravelRange = 100
+    stage_settings.SupplyVoltageMin = 12
+    stage_settings.SupplyVoltageMax = 36
     stage_settings.MaxCurrentConsumption = 0
-    stage_settings.HorizontalLoadCapacity = 0.5
-    stage_settings.VerticalLoadCapacity = 0.25
+    stage_settings.HorizontalLoadCapacity = 30
+    stage_settings.VerticalLoadCapacity = 7
     result = lib.set_stage_settings(id, byref(stage_settings))
 
     if result != Result.Ok:
@@ -505,7 +505,7 @@ def set_profile_8MT18_13(lib, id):
     motor_settings.SpeedConstant = 0
     motor_settings.SpeedTorqueGradient = 0
     motor_settings.MechanicalTimeConstant = 0
-    motor_settings.MaxSpeed = 2000
+    motor_settings.MaxSpeed = 5000
     motor_settings.MaxCurrent = 0
     motor_settings.MaxCurrentTime = 0
     motor_settings.NoLoadCurrent = 0
@@ -572,7 +572,7 @@ def set_profile_8MT18_13(lib, id):
     gear_information = gear_information_t()
 
     gear_information.Manufacturer = bytes([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
-    gear_information.PartNumber = bytes([49, 48, 47, 49, 32, 49, 54, 58, 49, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
+    gear_information.PartNumber = bytes([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
     result = lib.set_gear_information(id, byref(gear_information))
 
     if result != Result.Ok:
@@ -581,10 +581,10 @@ def set_profile_8MT18_13(lib, id):
 
     gear_settings = gear_settings_t()
 
-    gear_settings.ReductionIn = 16
-    gear_settings.ReductionOut = 1
+    gear_settings.ReductionIn = 5
+    gear_settings.ReductionOut = 2
     gear_settings.RatedInputTorque = 0
-    gear_settings.RatedInputSpeed = 0
+    gear_settings.RatedInputSpeed = 1500
     gear_settings.MaxOutputBacklash = 0
     gear_settings.InputInertia = 0
     gear_settings.Efficiency = 0
